==> 1.0.3.tar.gz: lib/model/wire_guard_profile_create_request.dart <==
part of forestvpn_api.api;

class WireGuardProfileCreateRequest {
  
  String deviceId = null;
  
  String deviceName = null;
  WireGuardProfileCreateRequest();

  @override
  String toString() {
    return 'WireGuardProfileCreateRequest[deviceId=$deviceId, deviceName=$deviceName, ]';
  }

  WireGuardProfileCreateRequest.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    deviceId = json['device_id'];
    deviceName = json['device_name'];
  }

  Map<String, dynamic> toJson() {
    Map <String, dynamic> json = {};
    if (deviceId != null)
      json['device_id'] = deviceId;
    if (deviceName != null)
      json['device_name'] = deviceName;
    return json;
  }

  static List<WireGuardProfileCreateRequest> listFromJson(List<dynamic> json) {
    return json == null ? List<WireGuardProfileCreateRequest>() : json.map((value) => WireGuardProfileCreateRequest.fromJson(value)).toList();
  }

  static Map<String, WireGuardProfileCreateRequest> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, WireGuardProfileCreateRequest>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) => map[key] = WireGuardProfileCreateRequest.fromJson(value));
    }
    return map;
  }

  // maps a json object with a list of WireGuardProfileCreateRequest-objects as value to a dart map
  static Map<String, List<WireGuardProfileCreateRequest>> mapListFromJson(Map<String, dynamic> json) {
    var map = Map<String, List<WireGuardProfileCreateRequest>>();
     if (json != null && json.isNotEmpty) {
       json.forEach((String key, dynamic value) {
         map[key] = WireGuardProfileCreateRequest.listFromJson(value);
       });
     }
     return map;
  }
}

==> 1.1.1.tar.gz: lib/model/wire_guard_profile_create_request.dart <==
part of forestvpn_api.api;

class WireGuardProfileCreateRequest {
  
  String deviceId = null;
  
  String deviceName = null;
  
  IOSDeviceInfo iosDeviceInfo = null;
  
  AndroidDeviceInfo androidDeviceInfo = null;
  WireGuardProfileCreateRequest();

  @override
  String toString() {
    return 'WireGuardProfileCreateRequest[deviceId=$deviceId, deviceName=$deviceName, iosDeviceInfo=$iosDeviceInfo, androidDeviceInfo=$androidDeviceInfo, ]';
  }

  WireGuardProfileCreateRequest.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    deviceId = json['device_id'];
    deviceName = json['device_name'];
    iosDeviceInfo = (json['ios_device_info'] == null) ?
      null :
      IOSDeviceInfo.fromJson(json['ios_device_info']);
    androidDeviceInfo = (json['android_device_info'] == null) ?
      null :
      AndroidDeviceInfo.fromJson(json['android_device_info']);
  }

  Map<String, dynamic> toJson() {
    Map <String, dynamic> json = {};
    if (deviceId != null)
      json['device_id'] = deviceId;
    if (deviceName != null)
      json['device_name'] = deviceName;
    if (iosDeviceInfo != null)
      json['ios_device_info'] = iosDeviceInfo;
    if (androidDeviceInfo != null)
      json['android_device_info'] = androidDeviceInfo;
    return json;
  }

  static List<WireGuardProfileCreateRequest> listFromJson(List<dynamic> json) {
    return json == null ? List<WireGuardProfileCreateRequest>() : json.map((value) => WireGuardProfileCreateRequest.fromJson(value)).toList();
  }

  static Map<String, WireGuardProfileCreateRequest> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, WireGuardProfileCreateRequest>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) => map[key] = WireGuardProfileCreateRequest.fromJson(value));
    }
    return map;
  }

  // maps a json object with a list of WireGuardProfileCreateRequest-objects as value to a dart map
  static Map<String, List<WireGuardProfileCreateRequest>> mapListFromJson(Map<String, dynamic> json) {
    var map = Map<String, List<WireGuardProfileCreateRequest>>();
     if (json != null && json.isNotEmpty) {
       json.forEach((String key, dynamic value) {
         map[key] = WireGuardProfileCreateRequest.listFromJson(value);
       });
     }
     return map;
  }
}
